TODO: need to update

GuessGame.py The purpose of guess game is to start a new game, cast a
random number between 1 to a variable called difficulty. The game will
get a number input from the...

MemoryGame.py The purpose of memory game is to display an amount of
random numbers to the users for 0.7 seconds and then prompt them from
the user for the numbers that he remember. If he was right with all the
numbers the user will win otherwise he will lose.

CurrencyRouletteGame.py This game will use t he free currency api to get
the current exchange rate from USD to ILS, will generate a new random
number between 1-100 a will ask the user what he thinks is the value of
the generated number from USD to ILS, depending on the user’s difficulty
his answer will be correct if the guessed value is between the interval
surrounding the correct answer
